@@ -15,7 +15,7 @@ use POSIX qw(ULONG_MAX LONG_MIN);
 
 use Class::Multimethods qw();
 
-our $VERSION = '0.02';
+our $VERSION = '0.03';
 our ($ROUND, $PREC);
 
 BEGIN {
@@ -23,6 +23,25 @@ BEGIN {
     $PREC  = 192;
 }
 
+BEGIN {
+    use Math::GMPz::V qw();
+
+    state $GMP_V_MAJOR = Math::GMPz::V::___GNU_MP_VERSION();
+    state $GMP_V_MINOR = Math::GMPz::V::___GNU_MP_VERSION_MINOR();
+
+    # Rmpq_cmp_z() is available only in gmp>=6.1.0
+    # https://rt.cpan.org/Public/Bug/Display.html?id=120910
+    if ($GMP_V_MAJOR < 6 or ($GMP_V_MAJOR == 6 and $GMP_V_MINOR < 1)) {
+        no warnings 'redefine';
+        *Math::GMPq::Rmpq_cmp_z = sub {
+            my ($q1, $z) = @_;
+            my $q2 = Math::GMPq::Rmpq_init();
+            Math::GMPq::Rmpq_set_z($q2, $z);
+            Math::GMPq::Rmpq_cmp($q1, $q2);
+        };
+    }
+}
+
 use overload
   '""' => \&stringify,
   '0+' => \&numify,
@@ -53,8 +72,11 @@ use overload
   '**' => sub { $_[2] ? __PACKAGE__->new($_[1])->pow($_[0]) : $_[0]->pow($_[1]) },
   '%'  => sub { $_[2] ? __PACKAGE__->new($_[1])->mod($_[0]) : $_[0]->mod($_[1]) },
 
-  '/' => sub { $_[2] ? $_[0]->inv->mul($_[1]) : $_[0]->div($_[1]) },
-  '-' => sub { $_[2] ? $_[0]->neg->add($_[1]) : $_[0]->sub($_[1]) },
+  #~ '/' => sub { $_[2] ? $_[0]->inv->mul($_[1]) : $_[0]->div($_[1]) },
+  #~ '-' => sub { $_[2] ? $_[0]->neg->add($_[1]) : $_[0]->sub($_[1]) },
+
+  '/' => sub { $_[2] ? __PACKAGE__->new($_[1])->div($_[0]) : $_[0]->div($_[1]) },
+  '-' => sub { $_[2] ? __PACKAGE__->new($_[1])->sub($_[0]) : $_[0]->sub($_[1]) },
 
   atan2 => sub { &Math::AnyNum::atan2($_[2] ? ($_[1], $_[0]) : ($_[0], $_[1])) },
 
@@ -2807,7 +2829,10 @@ Class::Multimethods::multimethod round => qw(* *) => sub {
         };
 
         sub seed {
-            my $z = _star2mpz($_[0]) // die "invalid seed: <<$_[0]>> (expected an integer)";
+            my $z = _star2mpz($_[0]) // do {
+                require Carp;
+                Carp::croak("invalid seed: <<$_[0]>> (expected an integer)");
+            };
             Math::MPFR::Rmpfr_randseed($state, $z);
             bless \$z, __PACKAGE__;
         }
@@ -2851,7 +2876,10 @@ Class::Multimethods::multimethod round => qw(* *) => sub {
         };
 
         sub iseed {
-            my $z = _star2mpz($_[0]) // die "invalid seed: <<$_[0]>> (expected an integer)";
+            my $z = _star2mpz($_[0]) // do {
+                require Carp;
+                Carp::croak("invalid seed: <<$_[0]>> (expected an integer)");
+            };
             Math::GMPz::zgmp_randseed($state, $z);
             bless \$z, __PACKAGE__;
         }
@@ -3953,7 +3981,8 @@ sub as_int {
     if (defined($y)) {
         $base = CORE::int($y);
         if ($base < 2 or $base > 36) {
-            die "[ERROR] base must be between 2 and 36, got $y\n";
+            require Carp;
+            Carp::croak("base must be between 2 and 36, got $y");
         }
     }
 
